# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities
from . import outputs

__all__ = [
    'GetPciResult',
    'AwaitableGetPciResult',
    'get_pci',
    'get_pci_output',
]

@pulumi.output_type
class GetPciResult:
    """
    A collection of values returned by getPci.
    """
    def __init__(__self__, comment=None, id=None, maps=None, mediated_devices=None, name=None):
        if comment and not isinstance(comment, str):
            raise TypeError("Expected argument 'comment' to be a str")
        pulumi.set(__self__, "comment", comment)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if maps and not isinstance(maps, list):
            raise TypeError("Expected argument 'maps' to be a list")
        pulumi.set(__self__, "maps", maps)
        if mediated_devices and not isinstance(mediated_devices, bool):
            raise TypeError("Expected argument 'mediated_devices' to be a bool")
        pulumi.set(__self__, "mediated_devices", mediated_devices)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def comment(self) -> str:
        """
        The comment of this PCI hardware mapping.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The unique identifier of this PCI hardware mapping data source.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def maps(self) -> Sequence['outputs.GetPciMapResult']:
        """
        The actual map of devices for the hardware mapping.
        """
        return pulumi.get(self, "maps")

    @property
    @pulumi.getter(name="mediatedDevices")
    def mediated_devices(self) -> bool:
        """
        Indicates whether to use with mediated devices.
        """
        return pulumi.get(self, "mediated_devices")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of this PCI hardware mapping.
        """
        return pulumi.get(self, "name")


class AwaitableGetPciResult(GetPciResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPciResult(
            comment=self.comment,
            id=self.id,
            maps=self.maps,
            mediated_devices=self.mediated_devices,
            name=self.name)


def get_pci(name: Optional[str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPciResult:
    """
    Retrieves a PCI hardware mapping from a Proxmox VE cluster.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    example = proxmoxve.Hardware.mapping.get_pci(name="example")
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingPci", example)
    ```


    :param str name: The name of this PCI hardware mapping.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('proxmoxve:Hardware/mapping/getPci:getPci', __args__, opts=opts, typ=GetPciResult).value

    return AwaitableGetPciResult(
        comment=pulumi.get(__ret__, 'comment'),
        id=pulumi.get(__ret__, 'id'),
        maps=pulumi.get(__ret__, 'maps'),
        mediated_devices=pulumi.get(__ret__, 'mediated_devices'),
        name=pulumi.get(__ret__, 'name'))


@_utilities.lift_output_func(get_pci)
def get_pci_output(name: Optional[pulumi.Input[str]] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPciResult]:
    """
    Retrieves a PCI hardware mapping from a Proxmox VE cluster.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    example = proxmoxve.Hardware.mapping.get_pci(name="example")
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingPci", example)
    ```


    :param str name: The name of this PCI hardware mapping.
    """
    ...
