# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .get_mappings import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_proxmoxve.hardware.mapping as __mapping
    mapping = __mapping
else:
    mapping = _utilities.lazy_import('pulumi_proxmoxve.hardware.mapping')

