# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetMappingsResult',
    'AwaitableGetMappingsResult',
    'get_mappings',
    'get_mappings_output',
]

@pulumi.output_type
class GetMappingsResult:
    """
    A collection of values returned by getMappings.
    """
    def __init__(__self__, check_node=None, checks=None, id=None, ids=None, type=None):
        if check_node and not isinstance(check_node, str):
            raise TypeError("Expected argument 'check_node' to be a str")
        pulumi.set(__self__, "check_node", check_node)
        if checks and not isinstance(checks, list):
            raise TypeError("Expected argument 'checks' to be a list")
        pulumi.set(__self__, "checks", checks)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="checkNode")
    def check_node(self) -> Optional[str]:
        """
        The name of the node whose configurations should be checked for correctness.
        """
        return pulumi.get(self, "check_node")

    @property
    @pulumi.getter
    def checks(self) -> Sequence['outputs.GetMappingsCheckResult']:
        """
        Might contain relevant diagnostics about incorrect configurations.
        """
        return pulumi.get(self, "checks")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The unique identifier of this hardware mappings data source.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        The identifiers of the hardware mappings.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the hardware mappings.
        """
        return pulumi.get(self, "type")


class AwaitableGetMappingsResult(GetMappingsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMappingsResult(
            check_node=self.check_node,
            checks=self.checks,
            id=self.id,
            ids=self.ids,
            type=self.type)


def get_mappings(check_node: Optional[str] = None,
                 type: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMappingsResult:
    """
    Retrieves a list of hardware mapping resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    example_pci = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="pci")
    example_usb = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="usb")
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsPci", example_pci)
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsUsb", example_usb)
    ```


    :param str check_node: The name of the node whose configurations should be checked for correctness.
    :param str type: The type of the hardware mappings.
    """
    __args__ = dict()
    __args__['checkNode'] = check_node
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('proxmoxve:Hardware/getMappings:getMappings', __args__, opts=opts, typ=GetMappingsResult).value

    return AwaitableGetMappingsResult(
        check_node=pulumi.get(__ret__, 'check_node'),
        checks=pulumi.get(__ret__, 'checks'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_mappings)
def get_mappings_output(check_node: Optional[pulumi.Input[Optional[str]]] = None,
                        type: Optional[pulumi.Input[str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMappingsResult]:
    """
    Retrieves a list of hardware mapping resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_proxmoxve as proxmoxve

    example_pci = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="pci")
    example_usb = proxmoxve.Hardware.get_mappings(check_node="pve",
        type="usb")
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsPci", example_pci)
    pulumi.export("dataProxmoxVirtualEnvironmentHardwareMappingsUsb", example_usb)
    ```


    :param str check_node: The name of the node whose configurations should be checked for correctness.
    :param str type: The type of the hardware mappings.
    """
    ...
